@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2004 Fons Adriaensen
+    Copyright (C) 2004-2009 Fons Adriaensen <fons@kokkinizita.net>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,9 +32,9 @@ public:
 
     void init (void)
     {
-        _f = 0.25;
-        _b = _g = 1.0;
-	_a = _s1 = _s2 = _z1 = _z2 = 0.0;
+        _f = 0.25f;
+        _b = _g = 1.0f;
+	_a = _s1 = _s2 = _z1 = _z2 = 0.0f;
     }
     
     void proc (int k, float *sig, float f, float b, float g)
@@ -51,36 +51,36 @@ public:
 
         if (f != _f)
 	{
-  	    if      (f < 0.5 * _f) f = 0.5 * _f;
-            else if (f > 2.0 * _f) f = 2.0 * _f;
+  	    if      (f < 0.5f * _f) f = 0.5f * _f;
+            else if (f > 2.0f * _f) f = 2.0f * _f;
             _f = f;
-            _s1 = -cos (2 * M_PI * f);
+            _s1 = -cosf (6.283185f * f);
             d1 = (_s1 - s1) / k;           
             u2 = true;
 	}             
        
         if (g != _g)
 	{
-            if      (g < 0.5 * _g) g = 0.5 * _g;
-            else if (g > 2.0 * _g) g = 2.0 * _g;
+            if      (g < 0.5f * _g) g = 0.5f * _g;
+            else if (g > 2.0f * _g) g = 2.0f * _g;
 	    _g = g;
-            _a = 0.5 * (g - 1.0);
+            _a = 0.5f * (g - 1.0f);
             da = (_a - a) / k;
             u2 = true;
 	}
 
         if (b != _b)
 	{
-            if      (b < 0.5 * _b) b = 0.5 * _b;
-            else if (b > 2.0 * _b) b = 2.0 * _b;
+            if      (b < 0.5f * _b) b = 0.5f * _b;
+            else if (b > 2.0f * _b) b = 2.0f * _b;
             _b = b; 
             u2 = true;
 	}
 
         if (u2)
 	{
-            b *= 4 * f;         
-            _s2 = (1 + _a - b) / (1 + _a + b);
+            b *= 7 * f / sqrtf (g);         
+            _s2 = (1 - b) / (1 + b);
             d2 = (_s2 - s2) / k;        
 	}
 
@@ -94,7 +94,7 @@ public:
             *sig++ -= a * (_z2 + s2 * y - x);                           
             y -= s1 * _z1;
             _z2 = _z1 + s1 * y;
-            _z1 = y + 1e-10;
+            _z1 = y + 1e-10f;
 	}
     }
     
