@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2004 Fons Adriaensen
+    Copyright (C) 2004-2009 Fons Adriaensen <fons@kokkinizita.net>
     
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,10 +23,10 @@
 #include "filters.h"
 
 #define NMODS 1
-#define VERSION "0.1.0"
+#define VERSION "0.3.0"
 
 
-static const char* maker = "Fons Adriaensen <fons.adriaensen@alcatel.be>";
+static const char* maker = "Fons Adriaensen <fons@kokkinizita.net>";
 static const char* copyr = "GPL";
 
 
@@ -179,6 +179,7 @@ static const LADSPA_Descriptor moddescr [NMODS] =
   }  
 };
 
+
 extern "C" const LADSPA_Descriptor *ladspa_descriptor (unsigned long i)
 {
   if (i >= NMODS) return 0;
